@@ -1,8 +1,9 @@
 # -*- coding: utf-8 -*-
 
-__version__ = '0.4.0'
+__version__ = '0.5.2'
 __project__ = 'diamond-patterns'
 __author__ = 'Ian Dennis Miller'
 __email__ = 'iandennismiller@gmail.com'
-__url__ = 'http://diamond-patterns.readthedocs.io/'
+__url__ = 'https://diamond-patterns.readthedocs.io/'
+__repo__ = 'https://github.com/iandennismiller/diamond-patterns/'
 __copyright__ = '2019 Ian Dennis Miller'
